@@ -93,6 +93,8 @@ module Nanoc::DataSources
         if is_binary && klass == Nanoc::Item
           meta                = (meta_filename && YAML.load_file(meta_filename)) || {}
           content_or_filename = content_filename
+        elsif is_binary && klass == Nanoc::Layout
+          raise "The layout file '#{content_filename}' is a binary file, but layouts can only be textual"
         else
           meta, content_or_filename = parse(content_filename, meta_filename, kind)
         end
@@ -255,7 +257,7 @@ module Nanoc::DataSources
       end
 
       # Split data
-      pieces = data.split(/^(-{5}|-{3})\s*$/)
+      pieces = data.split(/^(-{5}|-{3})[ \t]*\r?\n?/, 3)
       if pieces.size < 4
         raise RuntimeError.new(
           "The file '#{content_filename}' appears to start with a metadata section (three or five dashes at the top) but it does not seem to be in the correct format."
@@ -268,7 +270,7 @@ module Nanoc::DataSources
       rescue Exception => e
         raise "Could not parse YAML for #{content_filename}: #{e.message}"
       end
-      content = pieces[4..-1].join.strip
+      content = pieces[4]
 
       # Done
       [ meta, content ]
